pub struct Sled { /* fields omitted */ }Expand description
Sled is an impementation of a Collection using Sled to store the objects.
Open the given sled database.
Put the given value into the collection under the given
key. If the key already exists, it’s replaced with the given
value and the old value is returned. Read more
Find all the files that have the given prefix and iterate over
them. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The alignment of pointer.
The type for initializers.
pub unsafe fn init(init: <T as Pointable>::Init) -> usize
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.